@@ -13,7 +13,7 @@ from rest_framework.test import APIClient
 
 
 def id_generator(size=6, chars=string.ascii_uppercase + string.digits):
-    return ''.join(random.choice(chars) for _ in range(size))
+    return "".join(random.choice(chars) for _ in range(size))
 
 
 def random_float(min_value: float = 1.0, max_value: float = 1000.0) -> float:
@@ -29,14 +29,11 @@ def random_str() -> str:
 
 
 class SetupClass(TestCase):
-    username = 'admin'
+    username = "admin"
     pwd = ':L:3M3pFK"N$Y!Qj'
 
     def create_superuser(self):
-        u = User.objects.create_superuser(
-            username=self.username,
-            password=self.pwd
-        )
+        u = User.objects.create_superuser(username=self.username, password=self.pwd)
         u.save()
 
     def setUp(self):
@@ -44,54 +41,69 @@ class SetupClass(TestCase):
 
 
 class TestAdminTestCase(SetupClass):
-    MODULE = 'test'
+    MODULE = "test"
 
     def setUp(self):
         super().setUp()
         self.client = Client()
-        self.client.login(username=TestAdminTestCase.username, password=TestAdminTestCase.pwd)
+        self.client.login(
+            username=TestAdminTestCase.username, password=TestAdminTestCase.pwd
+        )
 
     def run_for_model(self, model: str, **kwargs):
-        if kwargs.get('is_check_add', True):
+        if kwargs.get("is_check_add", True):
             response = self.client.get(
-                reverse(f'admin:{self.MODULE}_{model}_add'),
-                follow=True
+                reverse(f"admin:{self.MODULE}_{model}_add"), follow=True
             )
             self.assertEqual(response.status_code, 200)
-            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_form.html')
+            self.assertEqual(
+                response.template_name[0],
+                f"admin/{self.MODULE}/{model}/change_form.html",
+            )
 
-        if kwargs.get('is_check_detail', True):
-            if kwargs.get('creation_parameters'):
+        if kwargs.get("is_check_detail", True):
+            if kwargs.get("creation_parameters"):
                 model_class = apps.get_model(self.MODULE, model)
-                test_instance = model_class.objects.create(**kwargs.get('creation_parameters'))
+                test_instance = model_class.objects.create(
+                    **kwargs.get("creation_parameters")
+                )
                 content_type = ContentType.objects.get_for_model(model_class)
                 response = self.client.get(
-                    reverse(f'admin:{content_type.app_label}_{content_type.model}_change', args=[test_instance.pk]),
-                    follow=True
+                    reverse(
+                        f"admin:{content_type.app_label}_{content_type.model}_change",
+                        args=[test_instance.pk],
+                    ),
+                    follow=True,
                 )
 
                 self.assertEqual(response.status_code, 200)
-                self.assertEqual(response.template_name[0],
-                                 f'admin/{content_type.app_label}/{content_type.model}/change_form.html')
+                self.assertEqual(
+                    response.template_name[0],
+                    f"admin/{content_type.app_label}/{content_type.model}/change_form.html",
+                )
 
         response = self.client.get(
-            reverse(f'admin:{self.MODULE}_{model}_changelist'),
-            follow=True
+            reverse(f"admin:{self.MODULE}_{model}_changelist"), follow=True
         )
         self.assertEqual(response.status_code, 200)
-        if kwargs.get('is_check_template', True):
-            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_list.html')
+        if kwargs.get("is_check_template", True):
+            self.assertEqual(
+                response.template_name[0],
+                f"admin/{self.MODULE}/{model}/change_list.html",
+            )
 
-        if kwargs.get('is_check_search', False):
+        if kwargs.get("is_check_search", False):
             response = self.client.get(
                 "{}?q={}".format(
-                    reverse(f'admin:{self.MODULE}_{model}_changelist'),
-                    "test"
+                    reverse(f"admin:{self.MODULE}_{model}_changelist"), "test"
                 ),
-                follow=True
+                follow=True,
             )
             self.assertEqual(response.status_code, 200)
-            self.assertEqual(response.template_name[0], f'admin/{self.MODULE}/{model}/change_list.html')
+            self.assertEqual(
+                response.template_name[0],
+                f"admin/{self.MODULE}/{model}/change_list.html",
+            )
 
 
 class BaseTestApiAuthorization(TestCase):
@@ -105,7 +117,9 @@ class BaseTestApiAuthorization(TestCase):
 
     def setUp(self) -> None:
         super().setUp()
-        user, created = User.objects.get_or_create(username=self.username, password=self.password)
+        user, created = User.objects.get_or_create(
+            username=self.username, password=self.password
+        )
         User.objects.create_superuser(
             username=self.admin_username,
             password=self.admin_password,
@@ -136,28 +150,6 @@ class BaseTestApiAuthorization(TestCase):
         self._test_superuser_access(endpoint=endpoint)
 
 
-class BaseTestAPIEndpointDoc(TestCase):
-    def setUp(self) -> None:
-        try:
-            self.user = User.objects.create_superuser(
-                username='admin',
-                email='admin@talk-point.de',
-                password='@12345678',
-            )
-        except Exception:
-            pass
-
-    def test_doc(self):
-        client = APIClient()
-
-        r = client.get('/docs/')
-        self.assertEqual(r.status_code, status.HTTP_401_UNAUTHORIZED)
-
-        client.force_authenticate(self.user)
-        r = client.get('/docs/')
-        self.assertEqual(r.status_code, status.HTTP_200_OK)
-
-
 class Representation(TestCase):
     """Tests all classes with a generate function from seeds.py for their string representation"""
 
